/**
 * 程序入口配置读取 项目开发时需要的自定义配置 另外：configuration为系统配置模块或者配置模板 这里可以扩展，支持多个系统共用一个项目：
 * 思路：在最开始的地方做一个sysCode的获取，然后在这个模块初始化时赋不同系统的configuration配置模块的引用，
 * 当然还要做修改的地方，比如地址栏hash处理，需要增加sysCode（涉及到的模块main和appUtils）
 */
define(function (require, exports, module) {
    var configuration = {
        /**
         * 平台，不传默认为0：
         * 0：pc或者手机浏览器、1：android壳子嵌phonegap、2：ios壳子嵌phonegap、3：ios壳子嵌AIR
         */
        "platform": "1",
        "defaultPage": {
            "pageCode": "account/login",
            "jsonParam": {}
        }, // 项目的默认页面
        "seaBaseUrl": "/plat/",
        "projName": "cyb",
        "firstLoadCss": ["/css/style.css"], // 项目中的需要先加载的css样式文件，如果多个，添加在数组里面
        "layerTheme": "g", // 各种弹出层主题样式，默认为系统自带
        /**
         * 后台返回结果集出参结构，类似errorNo、errorInfo的出参命名定义，
         * 防止不同项目的后台的出参命名不一致，而框架中写死导致解析出错，可由项目自己定义
         * 标准命名结构：errorNo、errorInfo，这里只为表示可以自定义，但后台必须统一
         */
        "resultsParser": {
            "errorNo": "error_no",
            "errorInfo": "error_info"
        },
        /**
         * 前端根据后台的errorNo做的过滤器配置，需要后台配合定义errorCode， 有的需要跳转页面，有的只做提示
         */
        "filters": {
            "-999": {
                "pageCode": "account/login",
                "jsonParam": {}
            } // 请重新登录
        },
        // 项目中模块的别名配置
        "pAlias": {
            "common": "cyb/scripts/common/common",
            "utils": "cyb/scripts/common/utils",
            "domain": "cyb/scripts/thinkive/domain",
            "service": "cyb/scripts/thinkive/service",
            "serviceImp": "cyb/scripts/thinkive/base/serviceImp"
        },
        /**
         * 第一次加载第一个业务模块前所需要的处理，即启动之后提供给外界初始化的接口，
         * 这个方法中避免写异步操作，或者保证异步影响其他代码逻辑
         * moduleAlias为项目通用模块配置的别名，moduleFuncName为执行的方法
         * 这个配置可以做很多事情，当你从业务模块逻辑上不好实现时，可以考虑这里！！ 不配默认为：{}
         */
        "firstLoadIntf": {
            "moduleAlias": "common",
            "moduleFuncName": "firstLoadFunc"
        },
        /**
         * 项目中需要调用到的常量、变量这里配置 调用方式，通过require("gconfig").global.*来调用
         */
        "global": {
            "op_source": "2", // 来源 pc/web：0 Android平板客户端：2
            // Android手机客户端：3 iPhone客户端：4
            "integrity_survey_type": "5",
            "isZhongZhuo": true, // 是否是中焯的

            // 生产环境
            "serverUrl": "https://kh.gzs.com.cn/cyb",  //  生产环境
            "serverPath": "https://kh.gzs.com.cn/cyb/servlet/json"  //  生产环境


            // 测试环境
//            "serverUrl": "http://121.33.247.54:8102/cyb",
//            "serverPath": "http://121.33.247.54:8102/cyb/servlet/json"
        }
    };

    // 暴露对外的接口
    module.exports = window.configuration = configuration;
});