/**
 * 程序入口配置读取 项目开发时需要的自定义配置 另外：configuration为系统配置模块或者配置模板 这里可以扩展，支持多个系统共用一个项目：
 * 思路：在最开始的地方做一个sysCode的获取，然后在这个模块初始化时赋不同系统的configuration配置模块的引用，
 * 当然还要做修改的地方，比如地址栏hash处理，需要增加sysCode（涉及到的模块main和appUtils）
 */
define(function (require, exports, module) {
    var configuration = {
        /**
         * 平台，不传默认为0：
         * 0：pc或者手机浏览器、1：android壳子嵌phonegap、2：ios壳子嵌phonegap、3：ios壳子嵌AIR
         */
        "platform": "1",
        "defaultPage": {
            "pageCode": "business/ydstart",
            "jsonParam": {}
        }, // 项目的默认页面
        /**
         * hSea根路径，项目中的文件uri最终会在项目访问的web路径后添加
         */
        "seaBaseUrl": "/plat/",
        /**
         * 项目模块名，默认为project
         */
        "projName": "open",
        "firstLoadCss": ["/css/style_guangzhou.css", "/css/style.css"
        ], // 项目中的需要先加载的css样式文件，如果多个，添加在数组里面
        /**
         * 后台返回结果集出参结构，类似error_no、error_info的出参命名定义，
         * 防止不同项目的后台的出参命名不一致，以便框架可取配置的值，由项目自己定义，但后台必须统一
         * 不配默认为：{"error_no": "error_no", "error_info": "error_info"}
         */
        "resultsParser": {"error_no": "error_no", "error_info": "error_info"},
        "layerTheme": "c", // 各种弹出层主题样式，默认为系统自带
        // ajax 超时时间，单位是 秒
        "ajaxTimeout": 90000,
        /**
         * 前端根据后台的errorNo做的过滤器配置，需要后台配合定义errorCode， 有的需要跳转页面，有的只做提示
         */
        "filters": {
            "-999": {
                "pageCode": "business/ydstart",
                "jsonParam": {}
            } // 请重新登录
        },
        // 项目中模块的别名配置
        "pAlias": {
            "common": "open/scripts/common/common",
            "utils": "open/scripts/common/utils",
            "domain": "open/scripts/thinkive/domain",
            "service": "open/scripts/thinkive/service",
            "serviceImp": "open/scripts/thinkive/base/serviceImp",
            "hIscroll": "plugins/iscroll/scripts/hIscroll"
        },
        /**
         * 第一次加载第一个业务模块前所需要的处理，即启动之后提供给外界初始化的接口，
         * 这个方法中避免写异步操作，或者保证异步影响其他代码逻辑
         * moduleAlias为项目通用模块配置的别名，moduleFuncName为执行的方法
         * 这个配置可以做很多事情，当你从业务模块逻辑上不好实现时，可以考虑这里！！
         * 不配默认为：{}
         */
        "firstLoadIntf": {"moduleAlias": "common", "moduleFuncName": "firstLoadFunc"},
        /**
         * 项目中需要调用到的常量、变量这里配置 调用方式，通过require("gconfig").global.*来调用
         */
        "global": {
            /* 广州单独的在修改渠道company的时候  要修改欢迎界面的图片\plat\open\index.html
             * 公版：images/gz_yd_01.png
             * 建行：images/JSYH.png
             * 同花顺：images/THS.png
             * */
            "company": "",//渠道,老钱庄：lqz  牛仔网:nzw 同花顺 :ths 优顾:yg  广州   财富赢家 cfyj  建设银行：jsyh
            //中焯版本的fixed_bank 为空 ，单独的fixed_bank=jsyh
            "fixed_bank": "",//建设银行  0081
            "protocol": "ajax", // 协议aaa
            "needConfirm": true, // 需要页面上进行用户回访
            "isZhongZhuo": true,  //是否是中焯的,true:中焯  false:单独

            //生产环境
            "vedioIp": "https://kh.gzs.com.cn:8095/servlet/json", //生产环境视频ip
            "serverPath" : "https://kh.gzs.com.cn:8095/servlet/json",// // 开户 -- 广州生产环境
            "imagePath" :"https://kh.gzs.com.cn:8095/servlet/buildimageservlet"// 图片地址-- 广州生产环境
            //测试环境
//            "vedioIp": "http://121.33.247.54:8095/servlet/json", //测试环境视频ip
//            "serverPath": "http://121.33.247.54:8095/servlet/json", // 开户-- 广州测试环境
//            "imagePath": "http://121.33.247.54:8095/servlet/buildimageservlet" // 图片地址-- 广州测试环境
        }
    };
    // 暴露对外的接口
    module.exports = window.configuration = configuration;
});