/**************************************************************
 @author liaohl
 @date: 2013-10-08
 @description 固定列滑动组件，固定列+滑动列
 @param config 配置参数
 	config.container 最外层容器元素，必传
	config.wrapper wrapper元素，必传
	config.wPerColumn 每列宽度数组，非必传，不传默认每列80(px)
	config.hasBorder 每列是否有边框，非必传，不传默认有边框
   
\/***********************使用案例***********************\/
1、定义
	var FIscroll = require("fIscroll");
	var myFIscroll = null;
2、初始化
	if(!myFIscroll){
		var config = {
			container: $('container对象选择器'), //container对象
			wrapper: $('wrapper对象选择器'), //wrapper对象
			wPerColumn: [100,80,80,80,130,80], //自定每列的宽度
		};
		myFIscroll = new FIscroll(config); //初始化
	};
	}
3、销毁（看情况而定是否需要销毁）
	myFIscroll.destroy();
	myFIscroll = null;
******************************************************************/
define(function (require, exports, module) {
	
	function FIscroll(config)
	{
		var This = this;
		var wrapperObj = null;
		
		/**
		 * 设置相关css和相关宽高，更新了htlm内容时需要调用该方法
		 */
		this.setCssHW = function() {
			var wPerColumn = config.wPerColumn, //每列自定义的宽度，undefined表示为固定宽度，数组表示自定义宽度
				fixedColLen = config.container.children(":eq(0)").children(":eq(0)").children().length, //固定的列数
				slideColLen = config.wrapper.children(":eq(0)").children(":eq(0)").children().length; //滑动的列数
			var fixedWidth = 0;
			var totalScrollerWidth = 0;
			
			//wrapper
			for(var i=0; i<fixedColLen; i++) {
				fixedWidth += wPerColumn ? wPerColumn[i] : 80;
				fixedWidth += 1; //边框处理
			}
			config.wrapper.css("left", fixedWidth+"px");
			config.wrapper.width(config.container.width()-fixedWidth); //wrapper的宽度要设定正确，否则不会有效果，先显示页面，再取实际宽度，否则定大概宽度
			//scroller
			for(var i=0; i<slideColLen; i++) {
				totalScrollerWidth += wPerColumn ? wPerColumn[i+fixedColLen] : 80;
				if(i!=slideColLen-1) {
					totalScrollerWidth += 1; //边框处理
				}
			}
			config.wrapper.children(":eq(0)").width(totalScrollerWidth);
			//固定列
			config.container.children(":eq(0)").children().each(function (i) {
				$(this).children().each(function (idx, item) {
					$(this).width(wPerColumn ? wPerColumn[idx] : 80);
					if(config.hasBorder===false) {
						$(this).css("border-right-width","0");
					}
				});
			});
			//滑动列
			config.wrapper.children(":eq(0)").children().each(function () {
				$(this).children().each(function (idx, item) {
					$(this).width(wPerColumn ? wPerColumn[idx+fixedColLen] : 80);
					if(config.hasBorder===false) {
						$(this).css("border-right-width","0");
					}
				});
			});
		};
		
		/**
		 * 滑动组件初始化
		 * 在初始化滑动组件前，滑动组件的DOM结构已完备，即如果dom节点是动态添加的，则在添加完成之后再初始化
		 */
		this.init = function() {
			//先设置相关css样式
			This.setCssHW();
			
			//销毁对象，优化内存
			if(wrapperObj != null) {
				wrapperObj.destroy();
				wrapperObj = null;
			}
			
			//初始化滑动对象
			var iScroll = require("iscroll");
			wrapperObj = new iScroll(config.wrapper[0], {
				snap: true,
				vScroll: false, //是否垂直滚动
				hScrollbar: false, //是否显示水平滚动条
				vScrollbar: false, //是否显示垂直滚动条
				onBeforeScrollStart: function(e) {
					var nodeType = e.explicitOriginalTarget ? e.explicitOriginalTarget.nodeName.toLowerCase() : 
						(e.target ? e.target.nodeName.toLowerCase() : '');
					if (nodeType != 'select' && nodeType != 'option' && nodeType != 'input' 
						&& nodeType != 'textarea') { //解决部分输入域或者下拉框没有默认行为
						if (this.absDistX > (this.absDistY + 5)) { //解决左右滑动不能上下拉动页面
							e.preventDefault();
						}
					}
				},
				onScrollEnd: function() {
					//处理左右滑动的小箭头图标
					var x = wrapperObj.x,
						wrapperX = config.wrapper.width(), 
						scrollerX = config.wrapper.children(":eq(0)").width();
					if(x == wrapperX - scrollerX) {
						config.wrapper.addClass("over");
					} else {
						config.wrapper.removeClass("over");
					}

					//解决第一次无法滑动的问题，左右滑动完成之后200ms让它可以上下滑动
					var self = this;
					if (self.touchEndTimeId) {
						clearTimeout(self.touchEndTimeId);
					}
					self.touchEndTimeId = setTimeout(function() {
						self.absDistX = 0;
						self.absDistY = 0;
					}, 200);
				}
			});
			config.container.find(".isc_item").show();
			
			//屏幕大小改变重新设置相关css和相关宽高，这里要实现resize全局管理器，把方法注册进去，否则后面的方法会覆盖前面的方法
			/*
			window.orientationchange  ? window.orientationchange = function() {This.setCssHW();} 
				: window.onresize  = function() {This.setCssHW();};
			*/	
		};
		
		/**
		 * 销毁引用，待释放内存
		 */
		this.destroy = function() {
			if(wrapperObj != null)
			{
				wrapperObj.destroy();
				wrapperObj = null;
			}
		};
		
		This.init();
	};
	//暴露对外的接口
	module.exports = FIscroll;
});