/**************************************************************
 @author liaohl
 @date: 2013-10-08
 @description 左右滑动组件（非分页形式，自由滑动）
 @param config 配置参数
 	config.wrapper wrapper元素，必传
	config.container container元素，必传
	config.onScrollEnd 滑动完成之后的处理，非必传
   
\/***********************使用案例***********************\/
1、定义
	var SHIscroll = require("shIscroll");
	var myShIscroll = null;
2、初始化
	if(!myShIscroll){
		var config = {
			wrapper: $('wrapper对象选择器'), //wrapper对象
			container: $('container对象选择器'), //container对象
			onScrollEnd: function(){
				var x = shIscroll.scroll.getXPosition();
				var maxScrollX = shIscroll.scroll.getMaxScrollX();
			}
		}
		myShIscroll = new SHIscroll(config); //初始化
	}
3、销毁（看情况而定是否需要销毁）
	myShIscroll.destroy();
	myShIscroll = null;
******************************************************************/
define(function (require, exports, module) {
	
	function SHIscroll(config)
	{
		var This = this;
		var wrapperObj = null;
		
		/**
		 * 设置相关css样式
		 */
		this.setCssHW = function() {
			var wrapper = config.wrapper;
			var scroller = wrapper.children();
			var container = config.container;
			var countNum = container.children().length;
			
//			var perTabWidth = container.children(":eq(0)").outerWidth(true);
//			scroller.width(perTabWidth*countNum);
//			container.children().outerWidth(perTabWidth);

			var perTabHeight = container.children(":eq(0)").outerHeight(true);
			container.children().outerHeight(perTabHeight);
			wrapper.outerHeight(perTabHeight);

			var totalWidth = 0;
			for(var i=0;i<countNum;i++){
				totalWidth += container.children().eq(i).outerWidth(true);
			}
			scroller.width(totalWidth);
			
			wrapper.css({
				"position": "absolute",
				"width": "100%"
			});
			scroller.css({
				"height": "100%",
				"float": "left"
			});
			container.children().css({
				"float": "left"
			});
			container.css({
				"display": "block",
				"float": "left",
				"width": "100%",
				"height": "100%"
			});
		};
		
		/**
		 * 滑动组件初始化
		 * 在初始化滑动组件前，滑动组件的DOM结构已完备，即如果dom节点是动态添加的，则在添加完成之后再初始化
		 */
		this.init = function() {
			//先设置相关css样式
			this.setCssHW();
			
			//销毁对象，优化内存
			if(wrapperObj != null) {
				wrapperObj.destroy();
				wrapperObj = null;
			}
			
			//初始化滑动对象
			var iScroll = require("iscroll");
			config.wrapperObj = new iScroll(config.wrapper[0], {
				vScroll: false, // 是否垂直滚动
				momentum: true, // 是否启动滑动惯性
				hScrollbar: false, // 是否显示水平滚动条
				vScrollbar: false, // 是否显示垂直滚动条
				onScrollEnd: function(e){
					if(config.onScrollEnd){
						config.onScrollEnd();
					}
				}
			});
		};
		
		/**
		 * 销毁引用，待释放内存
		 */
		this.destroy = function() {
			if(wrapperObj != null) {
				wrapperObj.destroy();
				wrapperObj = null;
			}
		};
		
		/**
		 * 返回滑动组件X的相对坐标
		 */
		this.getXPosition = function() {
			return config.wrapperObj.x;
		};
		
		/**
		 * 返回滑动组件X轴最大坐标值
		 */
		this.getMaxScrollX = function() {
			return config.wrapperObj.maxScrollX;
		};
		
		/**
		 * 滑动到指定元素
		 * @param ele 滚动到的jquery元素引用
		 * @param time 花费的时间 ms
		 */
		this.scrollToElement = function(ele, time) {
			config.wrapperObj.scrollToElement(ele[0], time);
		};
		
		This.init();
	};
	//暴露对外的接口
	module.exports = SHIscroll;
});