define(function (require, exports, module) {
	require("../css/keyPanel.css"); //加载所需的css
	require("../css/autocomplete.css"); //加载所需的css
	
	var appUtils = require("appUtils"),
		keyType1 = require('./keyType1');
		keyType2 = require('./keyType2');
		keyType3 = require('./keyType3');
		keyType4 = require('./keyType4');
		keyType5 = require('./keyType5');
		layerUtils = require("layerUtils"),
		inputEvent = null, // input 事件
		_KeyPanel = null; // 内部私有属性，代表一个 KeyPanel 对象
	
	/**
	 * 无参构造函数
	 */
	function KeyPanel()
	{
		_KeyPanel = Object.create({
				init: init,
				close: close
		});
		return _KeyPanel;
	}
	
	/**
	 * 键盘初始化
	 * @param curInputDOM 当前输入框的 DOM 对象，调用时在绑定事件中传 this 即可
	 * @param keyPanelType 键盘的类型
	 * 		1 电话键盘，2 数字键盘，3 纯数字键盘，4 英文键盘，5 股票键盘
	 * @param isPassword 是否是输入密码
	 * @param config 配置参数
	 * 		beforeInitFunc 初始化之前的函数
	 * 		afterInitFunc 初始化之后的函数
	 * 		beforeCloseFunc 键盘关闭之前的函数
	 * 		afterCloseFunc 键盘关闭之后的函数
	 */
	function init(curInputDOM, keyPanelType, isPassword, config)
	{
		console.log("%o", _KeyPanel)
		
		if(_KeyPanel && _KeyPanel.$input)
		{
			_KeyPanel.$prevInput = _KeyPanel.$input;
			var prevInputCurVal = _KeyPanel.$prevInput.find("em").html().trim();
			if(prevInputCurVal == "")
			{
				_KeyPanel.$prevInput.find("em").html(_KeyPanel.$prevInput.attr("placeholder"));
			}
			
			_KeyPanel.$prevInput.removeClass("active");
		}
		
		_KeyPanel.keyPanelType = keyPanelType;
		_KeyPanel.config = config;
		_KeyPanel.$input = $(curInputDOM); // 当前 input jquery 对象
		_KeyPanel.$inputEM = _KeyPanel.$input.find("em");
		_KeyPanel.inputPlaceholder = _KeyPanel.$input.attr("placeholder"); // 当前输入框的预留字
		_KeyPanel.$input.addClass("active");
		
		_KeyPanel.isPassword = typeof(isPassword) == "undefined" ? false : isPassword;
		
		_createKeyPanelHtml(); // 创建键盘 html 字符串
		
		if(_KeyPanel.config && typeof(_KeyPanel.config.beforeInitFunc) == "function")
		{
			_KeyPanel.config.beforeInitFunc();
		}
		
		_keyPanelInit(); // 执行初始化
		
		if(_KeyPanel.config && typeof(_KeyPanel.config.afterInitFunc) == "function")
		{
			_KeyPanel.config.afterInitFunc();
		}
	}
	
	/**
	 * 创建键盘 html 字符串
	 */
	function _createKeyPanelHtml()
	{
		_KeyPanel.keyPanelType = _KeyPanel.keyPanelType || '1';
		switch(Number(_KeyPanel.keyPanelType))
		{
			// 电话键盘
			case 1:
				_KeyPanel.keyPanelHtml = keyType1.createKeyPanelHtml();
				_KeyPanel.keyPanelId = keyType1.keyPanelId;
				break;
			// 数字键盘
			case 2:
				_KeyPanel.keyPanelHtml = keyType2.createKeyPanelHtml();
				_KeyPanel.keyPanelId = keyType2.keyPanelId;
				break;
			// 纯数字键盘
			case 3:
				_KeyPanel.keyPanelHtml = keyType3.createKeyPanelHtml();
				_KeyPanel.keyPanelId = keyType3.keyPanelId;
				break;
			// 英文键盘
			case 4:
				_KeyPanel.keyPanelHtml = keyType4.createKeyPanelHtml();
				_KeyPanel.keyPanelId = keyType4.keyPanelId;
				break;
			// 股票键盘
			case 5:
				_KeyPanel.keyPanelHtml = keyType5.createKeyPanelHtml();
				_KeyPanel.keyPanelId = keyType5.keyPanelId;
				break;
		}
	}
	
	/**
	 * 执行键盘初始化
	 **/
	function _keyPanelInit()
	{
		_KeyPanel.$keyPanel = $('#' + _KeyPanel.keyPanelId); // 键盘 jquery 对象
		
		if(_KeyPanel.$inputEM.html() == _KeyPanel.inputPlaceholder) // 当前输入框的值是预留字时
		{
			_KeyPanel.$inputEM.html(""); // 清空输入框
		}
		
		if(_KeyPanel.$keyPanel.length <= 0) // 键盘在文档中不存在时
		{
			_KeyPanel.$keyPanel = $(_KeyPanel.keyPanelHtml);
			$("body").append(_KeyPanel.$keyPanel);
		}
		
		_KeyPanel.$keyPanel.slideDown(100, function(){
			_setInputMainOffset(); // 设置输入框所在 DOM 结构主体元素位置的偏移，防止键盘挡住输入框
		}); // 显示当前键盘
		
		_KeyPanel.$keyPanel.css("display","block").siblings(".word_table").css("display","none"); // 隐藏其他键盘
		
		_BindKeyPanelEvent(); // 绑定键盘的点击事件
	}
	
	/**
	 * 绑定键盘的点击事件
	 */
	function _BindKeyPanelEvent()
	{
		var eventType = iBrowser.pc ? "click" : "touchstart";
		
		/**
		 * 防止 ios 拖动键盘出现黑色的阴影
		 */
		appUtils.bindEvent(_KeyPanel.$keyPanel, function(e){
			e.preventDefault();
		}, "touchmove");
		
		/**
		 * 绑定按键的点击事件
		 */
		appUtils.bindEvent(_KeyPanel.$keyPanel.find('a'), function(e){
			var $curA = $(this);
			var curValue = $curA.html();
			var btnType = $curA.attr('btn-type');
			var evt = e || window.event;
			var curInputVal = null; // 当前输入框的值
			var curEmVal = null; // 当前 em 的值
			if(_KeyPanel.$inputEM.length < 1)
			{
				_KeyPanel.$inputEM = $('<em></em>');
				_KeyPanel.$inputEM.html(_KeyPanel.$inputEM);
				_KeyPanel.$input.attr("value", "");
			}
			
			curEmVal = _KeyPanel.$inputEM.html();
			curInputVal = typeof(_KeyPanel.$input.attr("value")) == "undefined" ? "" : _KeyPanel.$input.attr("value");
			/**
			 * 自定属性 btn-type 1 字母或者数字，2 隐藏键盘，3 删除按钮，4 切换到数字键盘，5 切换到英文键盘，6 确定，7 空格，8 搜索，9 大小写切换，10 股票代码
			 */
			switch(Number(btnType))
			{
				// 普通按钮(字母、数字、小数点、空格)
				case 1:
					curEmVal = curEmVal + curValue;
					curInputVal = curInputVal + curValue;
					_KeyPanel.$inputEM.html(curEmVal);
					_KeyPanel.$input.attr("value", curInputVal.replace('&nbsp;', " "));
					if(_KeyPanel.isPassword)
					{
						_KeyPanel.$inputEM.html(curEmVal.replace(/[a-zA-Z0-9]/, "*"));
					}
					if(inputEvent) // inputEvent 不为空时
					{
						inputEvent = null;
					}
					inputEvent = document.createEvent("Events");
					inputEvent.initEvent("input", true, true);
					_KeyPanel.$input[0].dispatchEvent(inputEvent);
					break;
				// 隐藏按钮
				case 2: 
					close(); // 关闭键盘
					break;
				// 删除按钮
				case 3:
					if(curEmVal.length > 0) // 当前输入框有值时
					{
						if(/.*&nbsp;+$/.test(curEmVal))
						{
							curEmVal = curEmVal.slice(0, -6);
						}
						else
						{
							curEmVal = curEmVal.slice(0, -1);
						}
						curInputVal = curInputVal.slice(0, -1);
						_KeyPanel.$inputEM.html(curEmVal);
						_KeyPanel.$input.attr("value", curInputVal);
						if(inputEvent) // inputEvent 不为空时
						{
							inputEvent = null;
						}
						inputEvent = document.createEvent("Events");
						inputEvent.initEvent("input", true, true);
						_KeyPanel.$input[0].dispatchEvent(inputEvent);
					}
					break;
				// 切换到数字键盘
				case 4: 
					_KeyPanel.init(_KeyPanel.$input[0], 2, _KeyPanel.isPassword, _KeyPanel.config);
					break;
				// 切换到英文键盘
				case 5: 
					_KeyPanel.init(_KeyPanel.$input[0], 4, _KeyPanel.isPassword, _KeyPanel.config);
					break;
				// 确定按钮
				case 6: 
					close(); // 关闭键盘
					break;
				// 空格
				case 7: 
					curEmVal = curEmVal + "&nbsp;"
					curInputVal = curInputVal + " ";
					_KeyPanel.$inputEM.html(curEmVal);
					_KeyPanel.$input.attr("value", curInputVal.replace('&nbsp;', " "));
					if(_KeyPanel.isPassword)
					{
						_KeyPanel.$inputEM.html(curEmVal.replace(/(&nbsp;)$/, "*"));
					}
					if(inputEvent) // inputEvent 不为空时
					{
						inputEvent = null;
					}
					inputEvent = document.createEvent("Events");
					inputEvent.initEvent("input", true, true);
					_KeyPanel.$input[0].dispatchEvent(inputEvent);
					break;
				// 搜索
				case 8: 
					close(); // 关闭键盘
					break;
				// 大小写切换
				case 9: 
					var $letters = $("#" + _KeyPanel.keyPanelId + " .col10 a");
					var isSelected = $curA.hasClass("selected");
					if(isSelected)
					{
						$curA.removeClass('selected');
					}
					else
					{
						$curA.addClass('selected');
					}
					$letters.each(function(idx, curDOM){
						var curVal = $(curDOM).html();
						if(/^[a-z]$/.test(curVal))
						{
							$(curDOM).html(curVal.toUpperCase());
						}
						else if(/^[A-Z]$/.test(curVal))
						{
							$(curDOM).html(curVal.toLowerCase());
						}
					});
					break;
				// 股票代码
				case 10: 
					curValue = $curA.find("span").html();
					curEmVal = curEmVal + curValue;
					curInputVal = curInputVal + curValue;
					_KeyPanel.$inputEM.html(curEmVal);
					_KeyPanel.$input.attr("value", curInputVal.replace('&nbsp;', " "));
					if(_KeyPanel.isPassword)
					{
						_KeyPanel.$inputEM.html(curEmVal.replace(/\d$/, "*"));
					}
					if(inputEvent) // inputEvent 不为空时
					{
						inputEvent = null;
					}
					inputEvent = document.createEvent("Events");
					inputEvent.initEvent("input", true, true);
					_KeyPanel.$input[0].dispatchEvent(inputEvent);
					break;
			}
	        evt.stopPropagation ?evt.stopPropagation() : (evt.cancelBubble=true);
		}, eventType);
	}
	
	/**
	 * 关闭输入法
	 **/
	function close()
	{
		var curEmVal = _KeyPanel.$inputEM.html().trim();
		if(_KeyPanel.$keyPanel.length > 0)
		{
			if(_KeyPanel.$inputEM.length < 1)
			{
				_KeyPanel.$input.html("<em>" + curInputPlaceholder + "</em>");
			}
			else if(curEmVal == "")
			{
				_KeyPanel.$inputEM.html(_KeyPanel.inputPlaceholder);
			}
			
			_KeyPanel.$input.removeClass("active");
			
			if(_KeyPanel.$inputMain && _KeyPanel.inputMainExtraOffset > 0)
			{
				var inputMainTransform = _KeyPanel.$inputMain.css("transform").split(',');
				var translateY = inputMainTransform[inputMainTransform.length - 1].slice(0, -1);
				translateY = Number(translateY) + _KeyPanel.inputMainExtraOffset;
				_KeyPanel.$inputMain.css('transform', 'translateY(' + translateY + 'px)');
			}
			
			if(_KeyPanel.config && typeof(_KeyPanel.config.beforeCloseFunc) == "function")
			{
				_KeyPanel.config.beforeCloseFunc();
			}
			
			_KeyPanel.$keyPanel.slideUp(100, function(){
				$(this).remove();
				
				if(_KeyPanel.config && typeof(_KeyPanel.config.afterCloseFunc) == "function")
				{
					_KeyPanel.config.afterCloseFunc();
				}
			});
		}
	}
	
	/**
	 * 设置输入框所在 DOM 结构主体元素位置的偏移，防止键盘挡住输入框
	 */
	function _setInputMainOffset()
	{
		var $inputMain = _KeyPanel.$input.parents('[key-panel-main]'); // 输入框所在 DOM 结构主体元素位置的偏移
		var inputTop = _KeyPanel.$input.offset().top; // 输入框离屏幕顶部的距离
		var inputHeight = _KeyPanel.$input[0].clientHeight;
		var keyPanelTop = _KeyPanel.$keyPanel.offset().top;
		var inputMainExtraOffset = (inputTop + inputHeight + 5) - keyPanelTop; // 输入框所在 DOM 结构主体元素位置的偏移，多偏移五个像素
		var inputMainCurTop = $inputMain.css("margin-top");
		if($inputMain.attr("key-panel-main") == "false") // 属性值为 false，不执行设置位置位置便宜操作
		{
			return false;
		}
		_KeyPanel.inputMainExtraOffset = inputMainExtraOffset;
		_KeyPanel.$inputMain = $inputMain;
		if(inputMainExtraOffset > 0)
		{
			var inputMainTransform = $inputMain.css("transform") != "none" ? $inputMain.css("transform").split(',') : "";
			var translateY = 0; // 垂直方向的偏移
			if(inputMainTransform != "")
			{
				translateY = inputMainTransform[inputMainTransform.length - 1].slice(0, -1);
			}
			translateY = Number(translateY) - inputMainExtraOffset;
			_KeyPanel.$inputMain.css('transform', 'translateY(' + translateY + 'px)');
		}
	}

	//暴露对外的接口
	module.exports = KeyPanel;	
});