/**************************************************************
 @author liaohl
 @date: 2014-01-2
 @description 对日期组件方法的封装
**************************************************************/
define(function (require, exports, module) {
	
	require('mobiscroll');
	
	/**
	 * 初始化页面所有日期控件
	 * @parm containerId 初始化哪一个父元素下的所有时间输入域，一般为页面pageId
	 * @param config 各种配置参数(json对象形式)
	 * 		preset: date/time/datetime 日期/时间，可不传，默认“date”
	 *  	dateFormat: 日期输出格式，可不传，默认“yyyy-mm-dd”
	 *  	mode: 日期选择模式scroller,clickpick,mixed，可不传，默认“scroller”
	 *  	display: 显示方式 modal,inline,bubble,top,bottom，可不传，默认“modal”
	 *  	theme: 主题 ios、android-ics、android-ics light、jqm、default，可不传，默认ios系统为“ios”，Android系统为“android-ics light”
	 * 注意: 1、要求日期字段input都必须添加自定义属性data-dateplugin为mobiScroll
	 *		 2、一般在业务模块的bindPageEvent方法里面调用该方法
	 *		 3、如果某个日期控件需要初始值，则在给该input赋完值之后再调用该方法才能保证正常显示
	 */
	function initDateUI(containerId, config) 
	{
		config = config?config:{};
		var preset = config.preset, 
			dateFormat = config.dateFormat, 
			mode = config.mode, 
			display = config.display,
			theme = config.theme;
		
	    var opt = {
	        "preset": preset || 'date', 				//日期,datetime,date,time
	        "dateFormat": dateFormat || 'yyyy-mm-dd', 	//日期输出格式
	        "mode": mode || 'mixed', 					//日期选择模式scroller,clickpick,mixed
	        "display": display || 'modal', 				//显示方式 modal,inline,bubble,top,bottom
	        "dateOrder": 'yymmdd', 						//面板中日期排列格式
	        "theme": theme ? theme : (iBrowser.ios ? 'ios' : 'android-ics light'), //皮肤样式//jqm,default
	        "setText": '确定', 		//确认按钮名称
	        "cancelText": '取消',	//取消按钮名籍我
	        "dayText": '日',	 		//面板中日文字
	        "monthText": '月', 		//面板中月文字
	        "yearText": '年', 		//面板中年文字
	        "endYear": 2099, 		//结束年份
	        "hourText": '时',
	        "minuteText": '分',
	        "secText": '秒',
	        "lang": 'zh' 	//语言,默认空为英文
	    };
	    $("#"+containerId+" input[data-dateplugin='mobiScroll']").mobiscroll(opt);
	    
	    //增加默认值，如果在调用initDateUI方法之前，该input有value值，则该组件上也显示该值
	    $("#"+containerId+" input[data-dateplugin='mobiScroll']").each(function(){
	    	var thisVal = $(this).val();
	    	if(thisVal && /^(\d{1,4})(-|\/)(\d{1,2})\2(\d{1,2})$/.test(thisVal)){
	    		$(this).mobiscroll('setDate', new Date(thisVal.replaceAll("-", "/")), true, 0);
	    	}
	    });
	}
	
	var dateUtils = {
		"initDateUI": initDateUI
	};
	//暴露对外的接口
	module.exports = dateUtils;
});