/**************************************************************
 @author liaohl
 @date: 2014-01-09
 @description 分页组件
 @param pagingConfig 配置参数
 	container container元素，必传
 	wrapper wrapper元素，必传
 	scroller scroller元素，必传
 	pagingObj 分页对象（json对象），包括总页数、当前页数、分页滑动对象、初始化标识：{"totalPage":0,"curPage":0,"iscrollPage":null,"_init":false},
 	gotoPage 跳转页面的处理函数，该函数有目标页数targePageNo参数
\/***********************使用案例***********************\/
1、定义
var	pagingObj = {"totalPage":0,"curPage":0,"iscrollPage":null,"_init":false};
2、使用
pagingUtils.init({
	"container": $("container选择器"),
	"wrapper": $("wrapper选择器"),
	"scroller": $("scroller选择器"),
	"pagingObj": pagingObj,
	"gotoPage": function(targePageNo){
	}
});
******************************************************************/
define(function (require, exports, module) {
	//加载依赖模块
	var appUtils = require("appUtils");
	var layerUtils = require("layerUtils");
	var HIscroll = require("hIscroll");
	require("../css/paging.css"); //加载所需的css
	
	function init(pagingConfig){
		pagingConfig = pagingConfig?pagingConfig:{};
		var container = pagingConfig.container;
		var pagingObj = pagingConfig.pagingObj;
		
		container.find(".current_page").html(pagingConfig.pagingObj.curPage);
		container.find(".total_page").html(pagingConfig.pagingObj.totalPage);
		
		//初始化
		appUtils.bindEvent(container.find("ul .active") ,function(){
			 initScrollPage(pagingConfig);
		});
		//第一页
		appUtils.bindEvent(container.find("ul .home"),function(){
			if(pagingObj.curPage != 1){
				pagingConfig.gotoPage(1);
				container.find(".page_list").hide();
			}
		});
		//最后一页
		appUtils.bindEvent(container.find("ul .last"),function(){
			if(pagingObj.curPage != pagingObj.totalPage){
				pagingConfig.gotoPage(pagingObj.totalPage);
				container.find(".page_list").hide();
			}
		});
		//上一页
		appUtils.bindEvent(container.find("ul .pre"),function(){
			if(pagingObj.curPage > 1){
				pagingConfig.gotoPage(pagingObj.curPage-1);
				container.find(".page_list").hide();
			}
		});
		//下一页
		appUtils.bindEvent(container.find("ul .next"),function(){
			if(pagingObj.curPage < pagingObj.totalPage){
				pagingConfig.gotoPage(pagingObj.curPage+1);
				container.find(".page_list").hide();
			}
		});
		//指定页面
		appUtils.bindEvent(container.find(".page_list .page_input_page .btn"), function(){
			var container = pagingConfig.container;
			var pagingObj = pagingConfig.pagingObj;
			
			var totalPage = pagingObj.totalPage;
			var curPage = pagingObj.curPage;
			var inputPageNo = Number(container.find(".page_list .page_input_page .t1").val());
			if(inputPageNo>0 && inputPageNo <= totalPage && inputPageNo != curPage) { //有效执行跳转页面条件
				if(pagingConfig.gotoPage) {
					pagingConfig.gotoPage(inputPageNo);
					container.find(".page_list").hide();
				}
			} else {
				layerUtils.iMsg(-1,"请输入有效跳转的页数！");
			}
			container.find(".page_list .page_input_page .t1").val("");
		});
	}
	
	/**
	 * 设置分页滑动效果
	 */
	function initScrollPage(pagingConfig) 
	{
		var container = pagingConfig.container;
		var wrapper = pagingConfig.wrapper;
		var scroller = pagingConfig.scroller;
		var pagingObj = pagingConfig.pagingObj;
		
		container.find(".current_page").html(pagingConfig.pagingObj.curPage);
		container.find(".total_page").html(pagingConfig.pagingObj.totalPage);
		
		if(pagingObj.totalPage > 1) { //总页数大于1才有点击效果
			if(container.find(".page_list").is(":visible")) {
				container.find(".page_list").hide();
			} else {
				//初始化切分滑动片页数
				if(!pagingObj._init) {
					var totalPage = pagingObj.totalPage;
					var sliceTotalPage = totalPage%15==0 ? parseInt(totalPage/15) : parseInt(totalPage/15)+1; //需要切分的总页数
					var scrollerToTalEleStr = "";
					for(var i=1; i<=sliceTotalPage; i++) {
						var scrollerOneEleStr = "<div class=\"page_list_box\">";
						var len = (i==sliceTotalPage && totalPage%15!=0)?totalPage%15:15;
						for(var j=1; j<= len; j++) {
							var pageNo = (i-1)*15+j;
							scrollerOneEleStr += "<a id=\"pageNo"+(pageNo)+"\" href=\"javascript:void(0);\" data-idx=\""+pageNo+"\"><span>"+pageNo+"</span></a>";
						}
						scrollerOneEleStr += "</div>";
						scrollerToTalEleStr += scrollerOneEleStr;
					}
					scroller.html(scrollerToTalEleStr);
					
					//绑定每个元素的点击事件
					appUtils.bindEvent(scroller.find("a"),function() {
						var pointPageNo = $(this).attr("data-idx");
						var curPage = pagingObj.curPage;
						var delta = pointPageNo - curPage;
						if(pointPageNo != curPage) {
							pagingConfig.gotoPage(pointPageNo);
							container.find(".page_list").hide();
						}
					});
					
					pagingObj._init = true;
				}
				
				//设置选择的那一页选中效果
				var activePageNo = pagingObj.curPage;
				var activePageEle = scroller.find("a").eq(activePageNo-1);
				activePageEle.addClass("active").siblings().removeClass("active");
				
				//初始化左右滑动
				container.find(".page_list").show();
				if(!pagingObj.iscrollPage) {
					var config = {
						wrapper: wrapper, //wrapper对象
						scroller: scroller, //scroller对象
						perCount: 1,  //每个可视区域显示的子元素
						showTab: false, //是否有导航点
						auto: false, //是否自动播放
						onScrollEnd: function() { //分页模块针对左右滑动自定义字段，其他模块无影响
							var totalPage = pagingObj.totalPage;
							var sliceTotalPage = totalPage%15==0 ? parseInt(totalPage/15) : parseInt(totalPage/15)+1; //需要切分的总页数
							var currentPage = pagingObj.iscrollPage.getActivePage()+1; //滑动块的当前页，非分页数据的当前页
							container.find(".page_list h4 span").attr("class", "");
							if(currentPage == sliceTotalPage) {
								container.find(".page_list h4 span").addClass("no_next");
							}
							if(currentPage == 1) {
								container.find(".page_list h4 span").addClass("no_pre");
							}
						}
					};
					pagingObj.iscrollPage = new HIscroll(config); //初始化
				} else {
					pagingObj.iscrollPage.setCssHW();
				}
				
				//打开时指定到活动页面的滑块
				var curPage= pagingObj.curPage;
				var activePage = curPage%15==0 ? parseInt(curPage/15) : parseInt(curPage/15)+1;
				pagingObj.iscrollPage.scrollToPage(activePage-1, 0);
			}
		}
	}

	var pagingUtils = {
		"init": init
	};
	//暴露对外的接口
	module.exports = pagingUtils;
});