define(function(require, exports, module) {
	
	var layerUtils = require("layerUtils");
	
	/**
	 * 调用壳子插件的统一方法入口
	 * @param pluginName 调用的插件名
	 * @param success 成功的立即回调
	 * @param fail 失败的立即回调
	 * @param param 入参
	 */
	function callShellMethod(pluginName, success, fail, param) 
	{
		try {
			cordova.exec(function(echoValue) {
				if(success != null) {
					success(echoValue);
				}
			}, function(echoValue) {
				if(fail != null) {
					fail(echoValue);
				} else {
					layerUtils.iLoading(false);
					layerUtils.iAlert("插件调用失败:" + echoValue);
				}
			}, pluginName, pluginName, [param]);
		} catch (e) {
			layerUtils.iLoading(false);
			layerUtils.iAlert("不支持phonegap！"+e.message);
		}
	}
	
	/*****************************************监控的事件处理*************************************************/
	/**
	 * 手机锁屏处理 
	 */
	function onLockScreen()
	{
	}
	
	/**
	 * 手机断网处理
	 */
	function onOffline()
	{
		require("gconfig").global.isOnline = false;
		callShellMethod("toastPlugin", null , function() {
			layerUtils.iMsg(-1, "网络不可用，请检查您的网络设置!");
		},{"content":"网络不可用，请检查您的网络设置!", "type":0});
	}
	
	/**
	 * 手机联网处理
	 */
	function onOnline()
	{
		require("gconfig").global.isOnline = true;
		var connType = navigator.network.connection.type;
		if(connType == Connection.CELL_2G || connType == Connection.CELL_3G)
		{
			callShellMethod("toastPlugin", null , function() {
				layerUtils.iMsg(-1, "已经切换到2g/3g网络，请注意您的流量哦");
			},{"content":"已经切换到2g/3g网络，请注意您的流量哦", "type":0});
		} else {
			callShellMethod("toastPlugin", null , function() {
				layerUtils.iMsg(-1, "网络连接正常");
			},{"content":"网络连接正常", "type":0});
		}
	}
	
	/**
	 * 退出应用程序
	 */
	function exitApp()
	{
		var _exitApp = function() { callShellMethod("closeAppPlugin",null,null,{}); };
		callShellMethod("toastPlugin", null, function() {
			layerUtils.iConfirm("确认退出应用程序？", function(){
				callShellMethod("closeAppPlugin",null,null,{});
			}, function(){
				window.clearTimeout(intervalID);
		        document.removeEventListener("backbutton", _exitApp, false); // 注销返回键
		        document.addEventListener("backbutton", onBackKeyDown, false); // 返回键
			});}, {"content":"再按一次退出应用程序", "type":0});
		document.removeEventListener("backbutton", onBackKeyDown, false); // 注销返回键
		document.addEventListener("backbutton", _exitApp, false);// 绑定退出事件
		// 3秒后重新注册
		var intervalID = window.setTimeout(function() {
	        window.clearTimeout(intervalID);
	        document.removeEventListener("backbutton", _exitApp, false); // 注销返回键
	        document.addEventListener("backbutton", onBackKeyDown, false); // 返回键
		}, 2500);
	}

	/**
	 * Android手机返回键
	 */
	function onBackKeyDown() 
	{
		//判断是否直接退出
		if(!require("gconfig").isDirectExit) {
			//弹出层消失，弹出层抽象利于处理，返回上一级页面，page增加上一级页面
			var pageLevel = $(".page[data-display=block]").attr("data-pageLevel");
			if(pageLevel == "1") {
				exitApp();
			} else {
				var curPageCode = require("appUtils").getSStorageInfo("_curPageCode");
				curPageCode = (!curPageCode || curPageCode=="null")?"":curPageCode;
				require.async(require("gconfig").scriptsPath+curPageCode, function(page) {
					if(page.pageBack) {
						page.pageBack();
					} else {
						require("appUtils").pageBack();
					}
				});
			}
		} else {
			exitApp();
		}
	}
	
	/**
	 * phonegap主入口
	 * deviceready触发事件处理函数
	 * 当PhoneGap加载完毕后会触发"deviceready"事件。此时，可以开始与手机设备进行通讯
	 * 
	 * 添加phonegap监听：document.addEventListener("deviceready", onDeviceReady, false);
	 * 直接退出系统：navigator.app.exitApp();
	 */
	function onDeviceReady()
	{
		require("gconfig").global.isOnline = true;
		document.addEventListener('offline', onOffline, false); //断网
		document.addEventListener('online', onOnline, false); //联网
		document.addEventListener("backbutton", onBackKeyDown, false); //返回键
//		document.addEventListener("pause", onLockScreen, false); //锁屏，锁屏可能只是登录之后或者一段时间不操作之后才触发，按需要提到相应位置
		
//		//更新客户端的处理，这块可能需要移到默认页面去显示！！
//		getVersion(function(nowVersion) { //首先获取到当前app版本号
//			var version = nowVersion, plat = 1; //平台默认为android
//			if(iBrouser.ios) {
//				plat = 2; //2表示ios
//			}
//			var param = {"version": version, "plat": plat},  //app版本检查的入参
//				url = require("gconfig").global.serverPath + "login!versionchk.action"; //app版本检查的接口地址
//			appUtils.invokeServer(url, param, function(data) {
//				var errorcode = data.errorcode, errmsg = data.errmsg;
//				if(errorcode == 0) {
//					lastVersion = results.lastVersion, url = results.url;
//					updateClient(null, null, [data.needupdate, data.url]);
//				} else {
//					if(errmsg) layerUtils.iAlert(errmsg);
//				}
//			},true,true,false);
//		}, null);
	}
	
	var pgPlugin = {
		"onDeviceReady": onDeviceReady,
		"onBackKeyDown": onBackKeyDown,
		"callShellMethod": callShellMethod
	};
	module.exports = pgPlugin;
});